==> ngm-3.5.1.tar.gz: ngm-3.5.1/README.md <==
<h1 align = "center"> NeoSMS-Spammer </h1>
<p align = "center">
    A simple localhost web page creator NeoSMS-Spammer
    <br /> <br />
    <img alt = "Made with Python" src = "https://img.shields.io/badge/Made%20with-Python-%23FFD242?logo=python&logoColor=white">
    <img alt = "Downloads" src = "https://pepy.tech/badge/b0mb3r">
    <img alt = "Code style: black" src = "https://img.shields.io/badge/code%20style-black-000000.svg">
</p>

## 🚀 Install

1. Install Python version no lower than 3.7. You can do it this way:

    <h3> For Windows </h3>

    Download the installer from the [official site] (https://www.python.org/downloads/) and run it. Be sure to check the box! [Add Python to PATH] (https://user-images.githubusercontent.com/42045258/69171091-557d2780-0b0c-11ea-8adf-7f819357f041.png)

    <h3> For Android </h3>

    Install the [Termux] application (https://play.google.com/store/apps/details?id=com.termux), launch it and enter the command `pkg install python`.

2. Enter the following command ([where?] (Http://comp-profi.com/kak-vyzvat-komandnuyu-stroku-ili-konsol-windows/)):

`` `sh
pip3 install neov2 -U
`` ``

## 🚩 Launch

Everything is simple! Enter the command `neo-v2` or` neo` and the spammer interface will start. The command is accessible from any directory.

## ❌ Troubleshooting
If you are having problems with neo-v2, first follow these basic steps:
1. Run neo-v2 with the --repair flag:

    `` `sh
    neov2 --repair
    `` ``
2. Reboot the device on which the problem occurs

## 💻 Advanced Use

Watch [Wiki] (https://github.com/ELERMAND/neov2/wiki).

## 📝 License
<! --- No need to delete this, please 😐 ->
Project is licensed under [Mozilla Public License 2.0]
Project: https://github.com/ELERMAND/neov2

** Our telegram channel  **: https://t.me/neosms_spammer

==> ngm-3.5.2.tar.gz: ngm-3.5.2/README.md <==
<h1 align = "center"> NeoSMS-Spammer </h1>
<p align = "center">
    A simple localhost web page creator NeoSMS-Spammer
    <br /> <br />
    <img alt = "Made with Python" src = "https://img.shields.io/badge/Made%20with-Python-%23FFD242?logo=python&logoColor=white">
    <img alt = "Downloads" src = "https://pepy.tech/badge/b0mb3r">
    <img alt = "Code style: black" src = "https://img.shields.io/badge/code%20style-black-000000.svg">
</p>

## 🚀 Install

1. Install Python version no lower than 3.7. You can do it this way:

    <h3> For Windows </h3>

    Download the installer from the [official site] (https://www.python.org/downloads/) and run it. Be sure to check the box! [Add Python to PATH] (https://user-images.githubusercontent.com/42045258/69171091-557d2780-0b0c-11ea-8adf-7f819357f041.png)

    <h3> For Android </h3>

    Install the [Termux] application (https://play.google.com/store/apps/details?id=com.termux), launch it and enter the command `pkg install python`.

2. Enter the following command ([where?] (Http://comp-profi.com/kak-vyzvat-komandnuyu-stroku-ili-konsol-windows/)):

`` `sh
pip install ngm
`` ``

## 🚩 Launch

Everything is simple! Enter the command `ngm` and the spammer interface will start. The command is accessible from any directory.

## ❌ Troubleshooting
If you are having problems with ngm, first follow these basic steps:
1. Run ngm with the --repair flag:

    `` `sh
    ngm --repair
    `` ``
2. Reboot the device on which the problem occurs

## 💻 Advanced Use

Watch [Wiki] (https://github.com/ELERMAND/neov2/wiki).

## 📝 License
<! --- No need to delete this, please 😐 ->
Project is licensed under [Mozilla Public License 2.0]

** Our telegram channel  **: https://t.me/neosms_spammer
